import pygame
from pygame.locals import *
import sys

from .setup import *
from . import title, player, poop, bar

class Main():
    def __init__(self):
        pygame.init()
        pygame.display.set_caption(CAPTION)
        pygame.display.set_icon(pygame.image.load("resources/image/icon.png"))
        screen = pygame.display.set_mode(SCR_RECT.size)

        self.set_containers()

        self.title = title.Title()
        self.player = player.Player()
        self.bar = bar.Bar(STOCK, (16, 140))
        self.poop_start = False

        self.font = pygame.font.SysFont(None, 32)
        self.gameover = self.font.render("This is your UNCHI !", True, (255, 255, 255))
        self.gameover_pos = (((SCR_RECT.width / 2) - (self.gameover.get_width() / 2)), 100)

        global game_state
        game_state = TITLE
        clock = pygame.time.Clock()
        while True:
            clock.tick(30)
            self.update()
            self.draw(screen)
            pygame.display.update()
            self.key_handler()

    def update(self):
        global game_state
        if game_state == TITLE:
            self.title.update()
        elif game_state == PLAY:
            self.all.update()
            self.bar.update()
            self.collision_detection()

            if self.bar.value == 0 and len(self.poop_move) == 0:
                self.all.remove(self.player)
                game_state = GAMEOVER

            if not self.bar.value == 0:
                if self.poop_start == True:
                    self.bar.value -= 1
                    if self.bar.value < 10:
                        poop.Poop(self.player.rect.center, 20)
                    else:
                        poop.Poop(self.player.rect.center, 40)
        elif game_state == GAMEOVER:
            pass

    def draw(self, screen):
        global game_state
        if game_state == TITLE:
            self.title.draw(screen)
        elif game_state == PLAY:
            screen.fill((0, 0, 0))
            self.all.draw(screen)
            self.bar.draw(screen)
        elif game_state == GAMEOVER:
            screen.fill((0, 0, 0))
            self.all.draw(screen)
            screen.blit(self.gameover, self.gameover_pos)

    def key_handler(self):
        global game_state
        for event in pygame.event.get():
            if event.type == QUIT:
                pygame.quit()
                sys.exit()
            elif event.type == KEYDOWN and event.key == K_ESCAPE:
                pygame.quit()
                sys.exit()

            if game_state == TITLE:
                if not self.title.key_handler(event) == None:
                    game_state = PLAY
            elif game_state == PLAY:
                if event.type == KEYDOWN and event.key == K_SPACE:
                    self.poop_start = True
            elif game_state == GAMEOVER:
                if event.type == KEYUP and event.key == K_SPACE:
                    self.all.empty()
                    self.all.add(self.player)
                    self.poop_land.empty()
                    self.bar.value = STOCK
                    self.poop_start = False
                    game_state = TITLE

    def collision_detection(self):
        for poop in self.poop_move:
            if poop.rect.bottom == 420:
                poop.remove(self.poop_move)
                poop.add(self.poop_land)
                poop.landing = True
        poop_collided = pygame.sprite.groupcollide(self.poop_move, self.poop_land, False, False)
        for poop in poop_collided.keys():
            poop.remove(self.poop_move)
            poop.add(self.poop_land)
            poop.landing = True

    def set_containers(self):
        self.all = pygame.sprite.RenderUpdates()
        self.poop_move = pygame.sprite.Group()
        self.poop_land = pygame.sprite.Group()
        player.Player.containers = self.all
        poop.Poop.containers = self.all, self.poop_move
